#
# GDivPAL ("Genetic Diversity Patterns Across Landscapes"), June 2014
# Based on the method of Miller (2005)
# Script created by Simon Dellicour (Evolutionary Biology & Ecology - ULB)
#
# GDisPAL(rast, data, a, nberOfCores):
#
#   - rast: raster on which the interpollation will be performed
#   - data: [X Y Z], with X the vector of longitude coordinates (decimal
#       degrees), Y the vector of latitude coordinates (decimal
#       degrees) and Z the vector containing the genetic diversities zi's 
#       estimated at each corresponding sampled locality with corrdinates
#       (xi,yi)
#   - a: the distance weighting value (see Miller 2005 and AIS manual for 
#       further details and a discussion about the impact of this 
#       weighting parameter)
#   - nberOfCores: number of cores (CPU) available to parallelise the script
#

GDivPAL = function(rast, diversities, a, nberOfCores)
{    
	registerDoMC(cores=nberOfCores)
	rast1 = rast; rast2 = rast
	rast1[!is.na(rast1[])] = 0
	x_obs = diversities[,1]
	y_obs = diversities[,2]
	z_obs = diversities[,3]
	indices = which(!is.na(rast1[]))
	
	buffer = foreach(i = 1:length(indices)) %dopar%	{
	# for (i in 1:length(rast1[]))
		# {
			if (!is.na(rast1[indices[i]]))
				{
					print(paste(i,"/",length(indices)))
	    			xy = xyFromCell(rast1,indices[i])
	        		numerator = 0
	        		wi_sum = 0
	        		for (k in 1:length(z_obs))
	        			{
	        				wi = 0
	        				if ((abs(xy[1]-x_obs[k])<10^-10) & (abs(xy[2]-y_obs[k])<10^-10))
	        					{
	        						# wi = 1
	        					}
	        				else 
	        					{
	        						xy_obs = cbind(x_obs[k], y_obs[k])
									distance = rdist.earth(xy, xy_obs, miles=F, R=NULL)
									wi = (distance^(-(a/2)))
	        						# wi = ((x_obs[k]-xy[1])^2+(y_obs[k]-xy[2])^2)^(-(a/2))
	        						if (wi==Inf) print(c(i,k))
	        					}                
	        				wi_sum = wi_sum+wi
	        				numerator = numerator+(wi*z_obs[k])
	        			}
	        		z = numerator/wi_sum
	        	}	else	{
	        		z = NaN
	        	}
	        # rast1[indices[i]] = z
	        z
		}
	for (i in 1:length(indices))
		{
			rast1[indices[i]] = buffer[[i]]
		}	
	
	rast2 = rast1; rast2[is.na(rast[])] = NA
	return(rast2)
}    