#
# slidingWindowPi ("Genetic Distance Patterns Across Landscapes"), November 2016
# Script created by Simon Dellicour (Rega Institute - KULeuven)
#
# slidingWindowPi(template, inputName, numberOfLoci, radius):
#
#   - rast: raster on which the interpollation will be performed
#   - inputName : input name prefix as for the SPADS interface
#   - numberOfLoci : number of loci as for the SPADS interface
#   - radius : radius of the sliding window (in km)
#

slidingWindowPi = function(rast, inputName, numberOfLoci, radius)
{
	buffer = rast; buffer[] = 0
	points = rasterToPoints(buffer)[,c(1:2)]
	individuals = list(); mmds = list(); sequenceLengths = c()
	populations = read.table(paste(inputName,"_populations.txt",sep=""), header=F, colClasses="character")
	for (i in 1:numberOfLoci)
		{
			lon = c(); lat = c(); sequences = c()
			phy = scan(paste(inputName,"_locus",i,".phy",sep=""), what="", sep="\n", quiet=TRUE)
			for (j in 2:length(phy))
				{
					popID = unlist(strsplit(unlist(strsplit(phy[j]," "))[1],"-"))[2]
					if (popID%in%populations[,1])
						{
							lon = c(lon, as.numeric(populations[which(populations[,1]==popID),3]))
							lat = c(lat, as.numeric(populations[which(populations[,1]==popID),2]))
							sequences = c(sequences, unlist(strsplit(phy[j]," "))[length(unlist(strsplit(phy[j]," ")))])
						}
				}
			mmd = matrix(nrow=length(sequences), ncol=length(sequences))
			sequenceLengths = c(sequenceLengths, length(unlist(strsplit(sequences[1],""))))
			for (j in 2:length(sequences))
				{
					for (k in 1:(j-1))
						{
							seq1 = unlist(strsplit(sequences[k],""))
							seq2 = unlist(strsplit(sequences[j],""))
							mm = sum(seq1!=seq2)
							mmd[k,j] = mm; mmd[j,k] = mm
						}
				}
			individuals[[i]] = data.frame(lon, lat, sequences)
			mmds[[i]] = mmd
		}
	values = rast[]
	for (i in 1:length(values))
		{
			if (!is.na(values[i]))
				{
					coords = cbind(points[i,1], points[i,2])
					pis = c()
					for (j in 1:length(individuals))
						{
							pi = NA
							ds = diag(rdist.earth(coords[c(rep(1,length(individuals[[j]]$lon))),], cbind(individuals[[j]]$lon,individuals[[j]]$lat), miles=F))
							selection = which(ds<=radius); # print(min(ds))
							if (length(selection) > 1)
								{
									pi = 0; c = 0
									for (k in 2:length(selection))
										{
											for (l in 1:(k-1))
												{
													c = c+1
													pi = pi+(mmds[[j]][selection[l],selection[k]]/sequenceLengths[j])
												}
										}
									pi = pi/c	
								}
							pis = c(pis, pi)	
						}
					pis = pis[!is.na(pis)]
					if (length(pis) == 0) rast[i] = NA
					if (length(pis) > 0) rast[i] = mean(pis)
				}
		}
	return(rast)
}
