# If the "rgl", "fields", "rasters" and "geometry" packages are NOT already installed:
install.packages("rgl",dependencies=T); require("rgl")
install.packages("doMC",dependencies=T); require("doMC")
install.packages("fields",dependencies=T); require("fields")
install.packages("raster",dependencies=T); require("raster")
install.packages("geometry",dependencies=T); require("geometry")

# If the "rgl", "fields", "rasters" and "geometry" packages are already installed:
require("rgl")
require("doMC")
require("fields")
require("raster")
require("geometry")


## TUTORIAL 2: use of GDisPAL and GDivPAL functions 

source(file="SPADS_R_functions/GDisPAL.r") # to load the GDisPAL function
source(file="SPADS_R_functions/GDivPAL.r") # to load the GDivPAL function
a = 5 # interpolation parameter --> this is important to test different values
		# in order to investigate its impact on the interpolation result
nberOfCores = 1 # to specify the number of CPUs to use
template = raster("Chederae_GDisPAL/Chederae_template_raster.asc") # to load the template raster

# 1. Loading the SPADS outputs:
coordinates_Chederae = read.table(file="Chederae_GDisPAL/GDisPAL_Chederae_input_coordinates.txt",h=F) 
distances_Chederae_iid1 = read.table(file="Chederae_GDisPAL/GDisPAL_Chederae_input_regression_residuals_matrix_IID1.txt",h=F)
distances_Chederae_iid2 = read.table(file="Chederae_GDisPAL/GDisPAL_Chederae_input_regression_residuals_matrix_IID2.txt",h=F)
diversities_Chederae_Ar = read.table(file="Chederae_GDisPAL/GDivPAL_Chederae_input_Ar.txt",h=F)
diversities_Chederae_Pi = read.table(file="Chederae_GDisPAL/GDivPAL_Chederae_input_Pi.txt",h=F)

# 2. Building the interpolation surfaces (rasters):
iid1_Chederae = GDisPAL(template, coordinates_Chederae, distances_Chederae_iid1, a, nberOfCores)
iid2_Chederae = GDisPAL(template, coordinates_Chederae, distances_Chederae_iid2, a, nberOfCores)
ar_Chederae = GDivPAL(template, diversities_Chederae_Ar, a, nberOfCores)
pi_Chederae = GDivPAL(template, diversities_Chederae_Pi, a, nberOfCores)

# 3. Displaying the interpolation surfaces (rasters):
plot(iid1_Chederae,main="C. hederae (IID1)",cex.main=1,cex.axis=0.8,bty="n",box=F,axes=F,interpolate=T)
rect(xmin(iid1_Chederae),ymin(iid1_Chederae),xmax(iid1_Chederae),ymax(iid1_Chederae),xpd=T,lwd=0.25)
axis(1,c(ceiling(xmin(iid1_Chederae)),floor(xmax(iid1_Chederae))),pos=ymin(iid1_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=-0.8)
axis(2,c(ceiling(ymin(iid1_Chederae)),floor(ymax(iid1_Chederae))),pos=xmin(iid1_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=1)

plot(iid2_Chederae,main="C. hederae (IID2)",cex.main=1,cex.axis=0.8,bty="n",box=F,axes=F,interpolate=T)
rect(xmin(iid2_Chederae),ymin(iid2_Chederae),xmax(iid2_Chederae),ymax(iid2_Chederae),xpd=T,lwd=0.25)
axis(1,c(ceiling(xmin(iid2_Chederae)),floor(xmax(iid2_Chederae))),pos=ymin(iid2_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=-0.8)
axis(2,c(ceiling(ymin(iid2_Chederae)),floor(ymax(iid2_Chederae))),pos=xmin(iid2_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=1)

plot(ar_Chederae,main="C. hederae (Ar)",cex.main=1,cex.axis=0.8,bty="n",box=F,axes=F,interpolate=T)
rect(xmin(ar_Chederae),ymin(ar_Chederae),xmax(ar_Chederae),ymax(ar_Chederae),xpd=T,lwd=0.25)
axis(1,c(ceiling(xmin(ar_Chederae)),floor(xmax(ar_Chederae))),pos=ymin(ar_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=-0.8)
axis(2,c(ceiling(ymin(ar_Chederae)),floor(ymax(ar_Chederae))),pos=xmin(ar_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=1)

plot(pi_Chederae,main="C. hederae (Pi)",cex.main=1,cex.axis=0.8,bty="n",box=F,axes=F,interpolate=T)
rect(xmin(pi_Chederae),ymin(pi_Chederae),xmax(pi_Chederae),ymax(pi_Chederae),xpd=T,lwd=0.25)
axis(1,c(ceiling(xmin(pi_Chederae)),floor(xmax(pi_Chederae))),pos=ymin(pi_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=-0.8)
axis(2,c(ceiling(ymin(pi_Chederae)),floor(ymax(pi_Chederae))),pos=xmin(pi_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=1)

# 4. Saving the interpolation surfaces (rasters):
writeRaster(iid1_Chederae, file="Chederae_GDisPAL/Chederae_surface_IID1_a5.asc")
writeRaster(iid2_Chederae, file="Chederae_GDisPAL/Chederae_surface_IID2_a5.asc")
writeRaster(ar_Chederae, file="Chederae_GDisPAL/Chederae_surface_Ar_a5.asc")
writeRaster(pi_Chederae, file="Chederae_GDisPAL/Chederae_surface_Pi_a5.asc")


## Tutorial 3: GDivPAL with a preliminary sliding window application

source(file="SPADS_R_functions/slidingWindowPi.r") # to load the slidingWindowPi function
source(file="SPADS_R_functions/GDivPAL.r") # to load the GDivPAL function
template = raster("Chederae_GDisPAL/Chederae_template_raster.asc") # to load the template raster
inputName = "Chederae" # to specify the input name prefix as for the SPADS interface
numberOfLoci = 3 # to specify the number of loci as for the SPADS interface
radius = 50 # to define the radius of the slidingwindow (in km)
a = 5 # interpolation parameter
		
# 1. Preliminary sliding window based on nucleotide diversity values (pi):
slidingWindowPi_Chederae = slidingWindowPi(template, inputName, numberOfLoci, radius)

# 2. Building the interpolation surfaces (rasters):
diversities_Chederae_pi = rasterToPoints(slidingWindowPi_Chederae)
pi_Chederae = GDivPAL(template, diversities_Chederae_pi, a, nberOfCores)

# 3. Displaying the interpolation surfaces (rasters):
plot(pi_Chederae,main="C. hederae (Pi)",cex.main=1,cex.axis=0.8,bty="n",box=F,axes=F,interpolate=T)
rect(xmin(pi_Chederae),ymin(pi_Chederae),xmax(pi_Chederae),ymax(pi_Chederae),xpd=T,lwd=0.25)
axis(1,c(ceiling(xmin(pi_Chederae)),floor(xmax(pi_Chederae))),pos=ymin(pi_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=-0.8)
axis(2,c(ceiling(ymin(pi_Chederae)),floor(ymax(pi_Chederae))),pos=xmin(pi_Chederae),cex.axis=0.9,lwd=0,lwd.tick=0.25,padj=1)

# 4. Saving the interpolation surfaces (rasters):
writeRaster(pi_Chederae, file="Chederae_GDisPAL/Chederae_surface_Pi_r50km_a5.asc")

